summary.stationary: Summary for Posterior Model Probabilities
Description
Summary for a sample of posterior model probabilities (stationary).
Also provides the estimated effective sample size and summaries for all pairwise Bayes factors.
posterior samples of the stationary distribution (rows = samples; columns = models).
BF
whether to compute summaries for all pairwise Bayes factors.
logBF
whether to summarize log Bayes factors instead of Bayes factors.
...
passed to fit_dirichlet to estimate effective sample size
(e.g., maxit and abstol).
Details
Effective sample is estimated by fitting a Dirichlet model to the
posterior model probabilities (thereby assuming that samples were drawn from
an equivalent multinomial distribution based on independent sampling).
More precisely, sample size is estimated by the sum of the Dirichlet parameters
\(\sum\alpha[i]\) minus the prior sample size \(\epsilon*M^2\)
(where \(M\) is the number of sampled models and \(\epsilon\) the
prior parameter for each transition frequency).